@@ -322,7 +322,6 @@ This command updates the specified configuration values for the specified Kubern
 		"Boolean specifying whether to enable surge-upgrade for the cluster")
 	AddBoolFlag(cmdKubeClusterUpdate, doctl.ArgHA, "", false,
 		"Boolean specifying whether to enable the highly-available control plane for the cluster")
-	cmdKubeClusterUpdate.Flags().MarkHidden(doctl.ArgHA) // disabled until HA enablement launch
 	AddBoolFlag(cmdKubeClusterUpdate, doctl.ArgClusterUpdateKubeconfig, "",
 		true, "Boolean specifying whether to update the cluster in your kubeconfig")
 	AddBoolFlag(cmdKubeClusterUpdate, doctl.ArgSetCurrentContext, "", true,
@@ -648,7 +647,19 @@ func (s *KubernetesCommandService) RunKubernetesClusterList(c *CmdConfig) error
 		return err
 	}
 
-	return displayClusters(c, true, list...)
+	// Check the format flag to determine if the displayer should use the short
+	// layout of the cluster display. List uses the short version, but to format
+	// output that includes columns not in the short layout we need the full version.
+	var short = true
+	format, err := c.Doit.GetStringSlice(c.NS, doctl.ArgFormat)
+	if err != nil {
+		return err
+	}
+	if len(format) > 0 {
+		short = false
+	}
+
+	return displayClusters(c, short, list...)
 }
 
 // RunKubernetesClusterGetUpgrades retrieves available upgrade versions for a cluster.
