@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 # regenerated generated mocks
 
@@ -6,7 +6,7 @@ set -euo pipefail
 
 cd "do"
 
-GO111MODULE=off go get -u github.com/golang/mock/mockgen
+go install -mod=readonly github.com/golang/mock/mockgen@latest
 
 mockgen -source account.go -package=mocks AccountService > mocks/AccountService.go
 mockgen -source actions.go -package=mocks ActionService > mocks/ActionService.go
@@ -41,4 +41,4 @@ mockgen -source ../pkg/listen/listen.go -package=mocks Listen > mocks/Listen.go
 mockgen -source monitoring.go -package=mocks MonitoringService > mocks/MonitoringService.go
 mockgen -source reserved_ip_actions.go -package=mocks ReservedIPActionsService > mocks/ReservedIPActionsService.go
 mockgen -source reserved_ips.go -package=mocks ReservedIPsService > mocks/ReservedIPsService.go
-mockgen -source serverless.go -package=mocks ServerlessService > mocks/ServerlessService.go
\ No newline at end of file
+mockgen -source serverless.go -package=mocks ServerlessService > mocks/ServerlessService.go
